<?php

/**
 * Snippet to display Campaign Monitor update subscription form.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @package clearFusionCMS\module\campaignmonitor
 * @copyright Copyright (c) 2013 clearFusionCMS. All rights reserved.
 * @link http://clearfusioncms.com
 */

/* @var $tplEngine cfTemplateEngine */
$controller = $tplEngine->controller;

if(isset($listId) && isset($email)) {
	$cm = new campaignmonitor();

	// Get the users current information
	if(!($subscriber = $cm->getSubscriber($listId, $email))) {
		echo isset($notSubscribedMsg) ? $notSubscribedMsg : __('<p>You are not subscribed to this mailing list.</p>', 'campaignmonitor');
		return;
	}
	$fieldData = array();
	foreach($subscriber->CustomFields as $f) {
		$name = '[' . str_replace(' ', '', $f->Key) . ']';
		if(isset($fieldData[$name])) {
			if(is_array($fieldData[$name]))
				$fieldData[$name][] = $f->Value;
			else
				$fieldData[$name] = array($fieldData[$name], $f->Value);
		}
		else
			$fieldData[$name] = $f->Value;
	}

	// Cache field information
	if(!($fields = clearFusionCMS::getCache()->get("cfCampaignMonitor-fields-$listId")) && !is_array($fields)) {
		if(!is_array($fields = $cm->getFields($listId)))
			$fields = '-';
		clearFusionCMS::getCache()->store("cfCampaignMonitor-fields-$listId", $fields, is_array($fields) ? 86400 : 3600);
	}

	if(!is_array($fields)) {
		echo __("<p>Newsletter subscriptions are currently unavailable please try again later.</p>", 'campaignmonitor');
		return;
	}

	$form = new flForm(clearFusionCMS::getRequest(), 'campaignmonitorupdate', clearFusionCMS::getRequest()->getSelf());

	$emailField = new flFormElementEmail($form, 'cmemail', $email);
	$emailField->setLabel(__('Email Address', 'campaignmonitor'))
		->setRequired()
		->addValidator(new flFormValidatorRequired());

	$name = new flFormElementText($form, 'cmname', $subscriber->Name);
	$name->setLabel(__('Your Name', 'campaignmonitor'));

	foreach($fields as $f) {
		switch($f->DataType) {
			case 'Number': $elem = new flFormElementNumber($form, md5($f->Key), null, null, $fieldData[$f->Key]); break;
			case 'MultiSelectOne':
				$d = array();
				foreach($f->FieldOptions as $v)
					$d[$v] = $v;
				$elem = new flFormElementSelect($form, md5($f->Key), $fieldData[$f->Key], $d);
				break;
			case 'MultiSelectMany':
				$d = array();
				foreach($f->FieldOptions as $v)
					$d[$v] = $v;
				$elem = new flFormElementChecklist($form, md5($f->Key), is_array($fieldData[$f->Key]) ?$fieldData[$f->Key] : array($fieldData[$f->Key]), $d);
				break;
			default: $elem = new flFormElementText($form, md5($f->Key), $fieldData[$f->Key]); break;
		}

		$elem->setLabel($f->FieldName);
	}

	$submit = new flFormElementSubmit($form, 'cmupdate');
	$submit->setCaption(__('Update', 'campaignmonitor'));

	$showForm = true;
	if($form->isSubmitted() && $form->isValid()) {
		$d = array();
		foreach($fields as $f) {
			$v = $form->getElement(md5($f->Key))->getValue();
			if(is_array($v)) {
				foreach($v as $sel)
					$d[] = array('Key' => $f->Key, 'Value' => $sel);
			}
			else
				$d[] = array('Key' => $f->Key, 'Value' => $v);
		}

		if($cm->update($listId, $email, $emailField->getValue(), $name->getValue(), $d)) {
			$showForm = false;
			echo isset($updateMsg) ? $updateMsg : __("<p>Your details have been updated.</p>", 'campaignmonitor');
		}
		else
			echo $email->forceError(__('We are currently unable to update your subscription.', 'campaignmonitor'));
	}

	if($showForm)
		echo $form->render($tplEngine->getCodeBuffer());
}
